package com.example.onomatopoeiaback.service;


import com.example.onomatopoeiaback.domain.employee.Employee;
import com.example.onomatopoeiaback.domain.visit.Visit;
import com.example.onomatopoeiaback.exceptions.BadRequestException;
import com.example.onomatopoeiaback.exceptions.UnauthorizedException;
import com.example.onomatopoeiaback.repository.EmployeeRepository;
import com.example.onomatopoeiaback.repository.VisitRepository;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;

@Service
public class VisitService {
    private final VisitRepository visitRepository;
    private final EmployeeRepository employeeRepository;

    public VisitService(VisitRepository visitRepository, EmployeeRepository employeeRepository) {
        this.visitRepository = visitRepository;
        this.employeeRepository = employeeRepository;
    }

    public void open(String login, Long value) {
        Visit visit = visitRepository.getVisitByValue(value);
        Employee employee = employeeRepository.getEmployeesByLogin(login);

        if (employee == null) {
            throw new UnauthorizedException();
        }
        else if (visit == null) {
            throw new BadRequestException();
        }

        LocalDateTime localDateTime = LocalDateTime.now().truncatedTo(ChronoUnit.SECONDS);
        employee.setLastVisit(localDateTime);
        employeeRepository.saveAndFlush(employee);
    }
}
